@@ -1,5 +1,6 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING, OrderedDict
+from urllib import request
 if TYPE_CHECKING:
     from chilitools.api.connector import ChiliConnector
     from chilitools.api.response import ChiliResponse
@@ -178,6 +179,7 @@ class Resources:
       includeSubDirectories=True,
       includeFiles=True
     )
+    print(resp.text)
 
     items = resp.content['tree'].get('item')
 
@@ -250,7 +252,7 @@ class Documents:
   def getEditorURL(self, documentID: str, workSpaceID: str = None, viewPrefsID: str = None, constraintsID: str = None, viewerOnly: bool = None, forAnonymousUser: bool = None) -> ChiliResponse:
     return self.connector.makeRequest(
       method='get',
-      endpoint=f"resources/documents/{documentID}/urls/editor",
+      endpoint=f"/resources/documents/{documentID}/urls/editor",
       queryParams={'workSpaceID':workSpaceID, 'viewPrefsID':viewPrefsID, 'constraintsID':constraintsID, 'viewerOnly':viewerOnly, 'forAnonymousUser':forAnonymousUser}
     )
   def getXML(self, documentID: str) -> ChiliResponse:
@@ -304,7 +306,7 @@ class Documents:
       settingsXML = self.resources.getPDFSettingsXML(settingsID=settingsID).text
     return self.connector.makeRequest(
       method='post',
-      endpoint=f"resources/documents/{documentID}/representations/images",
+      endpoint=f"/resources/documents/{documentID}/representations/images",
       queryParams={'imageConversionProfileID':imageConversionProfileID, 'taskPriority':taskPriority},
       json={'settingsXML':settingsXML}
     )
@@ -359,11 +361,12 @@ class System:
         password = login["credentials"]["Password"]
 
       requestJSON = {'userName':username, 'password': password}
+      print(requestJSON)
 
     # Request
     return self.connector.makeRequest(
       method='post',
-      endpoint='system/apikey',
+      endpoint='/system/apikey',
       queryParams={'environmentNameOrURL': self.connector.getEnvironment()},
       json=requestJSON,
       authRequired=False
